ThaiIdInfo class

Represents extracted information from a Thai ID card number.

Constructors

ThaiIdInfo.parse(String input)
Parse information from a given ID card number string. Throws ArgumentError if the input isn't a 13-digit number (normalized).
factory

Properties

checkDigit String
Digit 13: Checksum digit.
no setter
group String
Digits 6-10: Group identifier (Birth volume/Leaflet).
no setter
hashCode int
The hash code for this object.
no setterinherited
officeCode String
Digits 2-5: Office code (Province + District code).
no setter
raw String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seq String
Digits 11-12: Sequence number.
no setter
type String
Digit 1: Category/Type of person.
no setter
typeDescription String
Get a descriptive label for the category/type (Digit 1).
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited