ThaiIdValidator class
Ready-to-use FormFieldValidators for Thai ID Card input fields.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
isStrictValid(
String value) → bool - Helper to check if a single string is valid (proxy to main class).
-
validate(
{String errorText = 'Invalid Thai ID Card Number', bool allowEmpty = false}) → FormFieldValidator< String> - Validates that the input is a valid Thai ID Card Number.